@@ -1,7 +1,7 @@
 import kate
 
-from kate_settings_plugins import kate_plugins_settings
-from utils import insertText
+from kate_core_plugins import insertText, setSelectionFromCurrentPosition
+from kate_settings_plugins import KATE_ACTIONS
 
 TEXT_JQUERY = """<script type="text/javascript">
     (function($){
@@ -15,6 +15,9 @@ TEXT_JQUERY = """<script type="text/javascript">
 """
 
 
-@kate.action(**kate_plugins_settings['insertReady'])
+@kate.action(**KATE_ACTIONS['insertReady'])
 def insertReady():
+    view = kate.activeView()
+    pos = view.cursorPosition()
     insertText(TEXT_JQUERY, start_in_current_column=True)
+    setSelectionFromCurrentPosition(pos, (3, 15), (3, 18))
