@@ -4,9 +4,9 @@ import kate
 
 from pyjslint import check_JSLint
 
-from utils import is_mymetype_js
+from kate_core_plugins import is_mymetype_js
 
-from kate_settings_plugins import kate_plugins_settings
+from kate_settings_plugins import KATE_ACTIONS
 from pyte_plugins.check_plugins import commons
 from pyte_plugins.check_plugins.check_all_plugins import checkAll
 
@@ -14,14 +14,15 @@ from pyte_plugins.check_plugins.check_all_plugins import checkAll
 pattern = re.compile(r"Lint at line (\d+) character (\d+): (.*)")
 
 
-@kate.action(**kate_plugins_settings['checkJslint'])
-def checkJslint(currentDocument=None, refresh=True, show_popup=True):
+@kate.action(**KATE_ACTIONS['checkJslint'])
+def checkJslint(currentDocument=None, refresh=True):
     if not (not currentDocument or (is_mymetype_js(currentDocument) and
                                     not currentDocument.isModified())):
         return
     if refresh:
         checkAll(currentDocument, ['checkJslint'],
                  exclude_all=not currentDocument)
+    move_cursor = not currentDocument
     currentDocument = currentDocument or kate.activeDocument()
     path = unicode(currentDocument.url().path())
     mark_key = '%s-jslint' % path
@@ -42,9 +43,9 @@ def checkJslint(currentDocument=None, refresh=True, show_popup=True):
                 })
 
     if len(errors_to_show) == 0:
-        if show_popup:
-            commons.showOk("JSLint Ok")
+        commons.showOk("JSLint Ok")
         return
 
-    commons.showErrors('JSLint Errors:', errors_to_show, mark_key,
-                       currentDocument, show_popup=show_popup)
+    commons.showErrors('JSLint Errors:',
+                       errors_to_show, mark_key, currentDocument,
+                       move_cursor=move_cursor)
