@@ -4,7 +4,7 @@ import kate
 import pep8
 
 
-from kate_settings_plugins import kate_plugins_settings
+from kate_settings_plugins import KATE_ACTIONS
 from pyte_plugins.check_plugins import commons
 from pyte_plugins.check_plugins.check_all_plugins import checkAll
 
@@ -31,18 +31,18 @@ class StoreErrorsChecker(pep8.Checker):
         return result
 
 
-@kate.action(**kate_plugins_settings['checkPep8'])
-def checkPep8(currentDocument=None, refresh=True, show_popup=True):
+@kate.action(**KATE_ACTIONS['checkPep8'])
+def checkPep8(currentDocument=None, refresh=True):
     if not commons.canCheckDocument(currentDocument):
         return
     if refresh:
         checkAll(currentDocument, ['checkPep8'],
                  exclude_all=not currentDocument)
+    move_cursor = not currentDocument
     currentDocument = currentDocument or kate.activeDocument()
     if currentDocument.isModified():
-        if show_popup:
-            kate.gui.popup('You must save the file first', 3,
-                           icon='dialog-warning', minTextWidth=200)
+        kate.gui.popup('You must save the file first', 3,
+                        icon='dialog-warning', minTextWidth=200)
         return
     path = unicode(currentDocument.url().path())
     mark_key = '%s-pep8' % unicode(currentDocument.url().path())
@@ -54,8 +54,7 @@ def checkPep8(currentDocument=None, refresh=True, show_popup=True):
     errors = checker.get_errors()
 
     if len(errors) == 0:
-        if show_popup:
-            commons.showOk('Pep8 Ok')
+        commons.showOk('Pep8 Ok')
         return
 
     errors_to_show = []
@@ -69,4 +68,5 @@ def checkPep8(currentDocument=None, refresh=True, show_popup=True):
             "message": error[3],
             })
     commons.showErrors('Pep8 Errors:', errors_to_show,
-                       mark_key, currentDocument, show_popup=show_popup)
+                       mark_key, currentDocument,
+                       move_cursor=move_cursor)
