@@ -1,7 +1,7 @@
 import kate
 
-from kate_settings_plugins import kate_plugins_settings
-from utils import insertText
+from kate_core_plugins import insertText, setSelectionFromCurrentPosition
+from kate_settings_plugins import KATE_ACTIONS
 
 TEXT_URLS = """from django.conf.urls.defaults import patterns, url
 
@@ -18,15 +18,18 @@ from django.template import RequestContext
 """
 
 
-@kate.action(**kate_plugins_settings['importUrls'])
+@kate.action(**KATE_ACTIONS['importUrls'])
 def importUrls():
     currentDocument = kate.activeDocument()
+    view = kate.activeView()
+    pos = view.cursorPosition()
     path = unicode(currentDocument.url().directory())
     path_split = path.split('/')
     application = path_split[len(path_split) - 1]
     insertText(TEXT_URLS % application)
+    setSelectionFromCurrentPosition(pos, (4, 16), (4, 19))
 
 
-@kate.action(**kate_plugins_settings['importViews'])
+@kate.action(**KATE_ACTIONS['importViews'])
 def importViews():
     insertText(TEXT_VIEWS)
